package com.agri.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.agri.system.domain.SysRequireList;

/**
 * 需求清单Service接口
 * 
 * @author lld
 * @date 2026-01-11
 */
public interface ISysRequireListService  extends IService<SysRequireList> {
    /**
     * 查询需求清单
     * 
     * @param id 需求清单主键
     * @return 需求清单
     */
    public SysRequireList selectSysRequireListById(Long id);

    /**
     * 查询需求清单列表
     * 
     * @param sysRequireList 需求清单
     * @return 需求清单集合
     */
    public List<SysRequireList> selectSysRequireListList(SysRequireList sysRequireList);

    /**
     * 新增需求清单
     * 
     * @param sysRequireList 需求清单
     * @return 结果
     */
    public int insertSysRequireList(SysRequireList sysRequireList);

    /**
     * 修改需求清单
     * 
     * @param sysRequireList 需求清单
     * @return 结果
     */
    public int updateSysRequireList(SysRequireList sysRequireList);

    /**
     * 批量删除需求清单
     * 
     * @param ids 需要删除的需求清单主键集合
     * @return 结果
     */
    public int deleteSysRequireListByIds(Long[] ids);

    /**
     * 删除需求清单信息
     * 
     * @param id 需求清单主键
     * @return 结果
     */
    public int deleteSysRequireListById(Long id);
}
